from __future__ import annotations

from collections.abc import Callable

import requests


class Client:
    def __init__(
        self,
        base_url: str,
        url_getter: Callable[[str], dict],
    ) -> None:
        self._base_url = base_url
        self._url_getter = url_getter

    def get_data(self, path: str) -> dict:
        url = f"{self._base_url}/{path}"
        data = self._url_getter(url)
        return data

    @staticmethod
    def create() -> Client:
        return Client(
            base_url="https://httpbin.org",
            url_getter=lambda url: requests.get(url).json(),
        )



import unittest

from niqodea.dummy.client import Client


class TestClient(unittest.TestCase):
    def setUp(self):
        self.base_url = "http://dummy.local"
        self.url_getter = lambda url: {"url": url}
        self.client = Client(self.base_url, self.url_getter)

    def test_get_data(self):
        data = self.client.get_data("get")
        self.assertEqual(data["url"], "http://dummy.local/get")


if __name__ == "__main__":
    unittest.main()
